package edu.nyu.scps.location;

import android.app.AlertDialog;
import android.content.Context;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.webkit.JavascriptInterface;
import android.webkit.JsResult;
import android.webkit.WebChromeClient;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;


public class MainActivity extends ActionBarActivity implements LocationListener {
    boolean haveLatLng = false;
    boolean havePage = false;
    float latitude;
    float longitude;
    WebView webView;
    LocationManager locationManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        locationManager = (LocationManager)getSystemService(Context.LOCATION_SERVICE);

        webView = (WebView)findViewById(R.id.webView);

        WebSettings webSettings = webView.getSettings();
        webSettings.setJavaScriptEnabled(true);
        webView.setVerticalScrollBarEnabled(false);

        webView.setWebViewClient(new WebViewClient() {
            //Called when the WebView has finished loading the page of HTML.
            @Override
            public void onPageFinished(WebView view, String url) {
                havePage = true;
                if (haveLatLng) {
                    int zoom = 18;
                    String javascript = String.format("javascript:mapFunction(%f, %f, %d)",
                            latitude, longitude, zoom);
                    view.loadUrl(javascript);

                    javascript = String.format("javascript:f(%f, %f)", latitude, longitude);
                    view.loadUrl(javascript);
                    locationManager.removeUpdates(MainActivity.this);
                }
            }
        });

        webView.setWebChromeClient(new WebChromeClient() {
            //Called when the JavaScript alert function is called.
            @Override
            public boolean onJsAlert(WebView view, String url, String message, JsResult result) {
                Toast toast = Toast.makeText(MainActivity.this, "onJsAlert " + url + " " + message,
                        Toast.LENGTH_LONG);
                toast.show();

                //Cause the JavaScript alert function to return.
                result.confirm();
                return true;
            }
        });

        //Create a new Java object, and specify the name it will have when it
        //appears in the JavaScript program.
        webView.addJavascriptInterface(new DualCitizen(), "dualCitizen");
        webView.loadUrl("file:///android_asset/map.html");
    }

    //GPS is expensive, so use it only when app is exposed on screen.

    @Override
    public void onResume() {
        super.onResume();
        locationManager.requestLocationUpdates(
                LocationManager.GPS_PROVIDER,	//or LocationManager.NETWORK_PROVIDER, or both
                0L,		//minimum time interval (milliseconds) between notifications
                0.0f,		//minimum change in distance (meters) between notifications
                this
        );
    }

    @Override
    public void onPause() {
        super.onPause();
        locationManager.removeUpdates(this);
    }

    @Override
    public void onLocationChanged(Location location) {
        // Called when a new location is found by the network location provider.
        haveLatLng = true;
        latitude = (float)location.getLatitude();
        longitude = (float)location.getLongitude();

       if (havePage) {
           String javascript = String.format("javascript:mapFunction(%f, %f, %d)",
                   latitude, longitude, 18);
           webView.loadUrl(javascript);

           javascript = String.format("javascript:f(%f, %f)", latitude, longitude);
           webView.loadUrl(javascript);
           locationManager.removeUpdates(this);
       }
    }

    class DualCitizen {
        //This method, although written in Java, can be called in a JavaScript statement.
        @JavascriptInterface
        public void setZipcode(String z) {
            int zipcode = Integer.parseInt(z);
            //Toast toast = Toast.makeText(MainActivity.this, "Zipcode is " + zipcode, Toast.LENGTH_LONG);
            //toast.show();

            //The builder will build the dialog.
            AlertDialog.Builder builder = new AlertDialog.Builder(MainActivity.this);

            //Tell the builder about the dialog you want it to create.
            builder.setTitle("Zipcode");
            builder.setMessage("Your zipcode is " + zipcode);
            //null because we want the positive button to do nothing
            //except dismisss the dialog.
            builder.setPositiveButton("OK", null);

            //Now that you've finished describing the dialog,
            //tell the builder to create it.
            AlertDialog alertDialog = builder.create();
            alertDialog.show();
        }
    }

    @Override
    public void onStatusChanged(String provider, int status, Bundle extras) {

    }

    @Override
    public void onProviderEnabled(String provider) {
    }

    @Override
    public void onProviderDisabled(String provider) {
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }
}
